use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Stevan
Little
stevan
Infinity
Interactive
Inc
Karen
Etheridge
ether
Tomas
Doran
bobtfish
Yuval
Kogman
nothingmuch
Florian
Ragwitz
rafl
Brandon
Black
blblack
Shlomi
Fish
shlomif
Hans
Dieter
Pearcey
hdp
Ryan
Johnson
ryan
Nelo
Onyiah
nelo
Ricardo
SIGNES
rjbs
Ævar
Arnfjörð
Bjarmason
avarab
Damien
Krotkine
dkrotkine
Hinrik
Örn
Sigurðsson
hinrik
Devin
Austin
devin
Todd
Hepler
thepler
Chris
Prather
chris
John
Goulah
jgoulah
Jesse
Luehrs
doy
Justin
Hunter
justin
Drew
Taylor
drew
Dagfinn
Ilmari
Mannsåker
ilmari
Gordon
Irving
goraxe
Jonathan
Swartz
swartz
Olaf
Alders
olaf
lib
MooseX
Getopt
Basic
Dashes
GLD
Meta
Attribute
NoGetopt
Trait
OptionTypeMap
ProcessedArgv
Strict
